@@ -73,7 +73,7 @@ spwb_ldrExploration<-function(x, soil, meteo, cohorts = NULL,
   cc <- which(mExplore == T, arr.ind = T)
   
   # Reset input
-  spwb_resetInputs(x, soil)
+  resetInputs(x, soil)
   
   for(ci in 1:length(cohorts)){
     coh = cohorts[ci]
@@ -86,7 +86,7 @@ spwb_ldrExploration<-function(x, soil, meteo, cohorts = NULL,
     x_1sp$above <- x$above[sp,,drop = FALSE]
     x_1sp$below <- x$below
     x_1sp$below$V <- x$below$V[sp,,drop = FALSE] 
-    x_1sp$paramsBase <- x$paramsBase[sp,,drop = FALSE] 
+    x_1sp$paramsInterception <- x$paramsInterception[sp,,drop = FALSE] 
     x_1sp$paramsTransp <- x$paramsTransp[sp,,drop = FALSE] 
     x_1sp$Transpiration <- x$Transpiration[sp,drop = FALSE] 
     x_1sp$Photosynthesis <- x$Photosynthesis[sp,drop = FALSE] 
@@ -97,15 +97,15 @@ spwb_ldrExploration<-function(x, soil, meteo, cohorts = NULL,
       x_1sp$below$VCroot_kmax <- x$below$V[sp,,drop = FALSE] 
       x_1sp$paramsAnatomy <- x$paramsAnatomy[sp,,drop = FALSE] 
       x_1sp$paramsWaterStorage <- x$paramsWaterStorage[sp,,drop = FALSE] 
-      x_1sp$PLCstem <- x$PLCstem[sp,drop = FALSE] 
+      x_1sp$StemPLC <- x$StemPLC[sp,drop = FALSE] 
       x_1sp$Einst <- x$Einst[sp,drop = FALSE] 
-      x_1sp$psiRhizo <- x$psiRhizo[sp,,drop = FALSE] 
-      x_1sp$psiRootCrown <- x$psiRootCrown[sp,drop = FALSE] 
-      x_1sp$psiSympStem <- x$psiSympStem[sp,drop = FALSE] 
-      x_1sp$psiStem1 <- x$psiStem1[sp,drop = FALSE] 
-      x_1sp$psiStem2 <- x$psiStem2[sp,drop = FALSE] 
-      x_1sp$psiSympLeaf <- x$psiSympLeaf[sp,drop = FALSE] 
-      x_1sp$psiLeaf <- x$psiLeaf[sp,drop = FALSE] 
+      x_1sp$RhizoPsi <- x$RhizoPsi[sp,,drop = FALSE] 
+      x_1sp$RootCrownPsi <- x$RootCrownPsi[sp,drop = FALSE] 
+      x_1sp$StemSympPsi <- x$StemSympPsi[sp,drop = FALSE] 
+      x_1sp$StemPsi1 <- x$StemPsi1[sp,drop = FALSE] 
+      x_1sp$StemPsi2 <- x$StemPsi2[sp,drop = FALSE] 
+      x_1sp$LeafSympPsi <- x$LeafSympPsi[sp,drop = FALSE] 
+      x_1sp$LeafPsi <- x$LeafPsi[sp,drop = FALSE] 
     }
     x_1sp$control$verbose <- F
     
@@ -159,17 +159,21 @@ spwb_ldrExploration<-function(x, soil, meteo, cohorts = NULL,
         f
       }
       if(x_1sp$control$transpirationMode=="Granier") {
-        PsiMin[ci,i,j] <- mean(aggregate(s_res$PlantPsi[op_days], 
+        PsiMin[ci,i,j] <- mean(aggregate(s_res$Plants$PlantPsi[op_days], 
                                          by = list(years[op_days]),
                                          FUN = function(x) min(ma(x)))$x)
       } else {
-        PsiMin[ci,i,j] <- mean(aggregate(s_res$StemPsi[op_days], 
+        PsiMin[ci,i,j] <- mean(aggregate(s_res$Plants$StemPsi[op_days], 
                                          by = list(years[op_days]),
                                          FUN = function(x) min(ma(x)))$x)
       }
       # if(verbose) print(s_res$spwbInput)
-      E[ci,i,j] <- mean(s_res$PlantTranspiration[op_days], na.rm=T)
-      An[ci,i,j] <- mean(s_res$PlantPhotosynthesis[op_days], na.rm=T)
+      E[ci,i,j] <- mean(s_res$Plants$Transpiration[op_days], na.rm=T)
+      if(x_1sp$control$transpirationMode=="Granier") {
+        An[ci,i,j] <- mean(s_res$Plants$Photosynthesis[op_days], na.rm=T)
+      } else {
+        An[ci,i,j] <- mean(s_res$Plants$NetPhotosynthesis[op_days], na.rm=T)
+      }
       setTxtProgressBar(pb, row)
     }
     cat("\n")
